# SEKV-E

SEKV-E is a Python-based parameters extractor for the simplified EKV model, which is developed by ICLAB, EPFL. While it has been developed to serve the needs of low-power analog circuit designs.

## Install

The project is present on `pip` and `conda-forge`.

### Conda

To get the package in your `conda` environment:

```console
conda install -c conda-forge sekve
```

### PyPI

To install the project via `pip`:

```console
pip install sekve
```

### Git

To clone directly the project in your local directory:

```console
git clone https://gitlab.com/moscm/sekv-e.git
```

## Authors and acknowledgment

Hung-Chi Han, doctoral assistant in ICLAB, EPFL, Lausanne, Switzerland.
Vicente Carbon, master student in ICLAB, EPFL, Lausanne, Switzerland.

## License

see [LICENSE](LICENSE).
